@@ -1,8 +1,11 @@
-#ifndef lint
-static char const 
-yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.34 2002/04/09 11:39:05 ru Exp $";
-#endif
 #include <stdlib.h>
+#ifndef lint
+#ifdef __unused
+__unused
+#endif
+static char const 
+yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.37 2003/02/12 18:03:55 davidc Exp $";
+#endif
 #define YYBYACC 1
 #define YYMAJOR 1
 #define YYMINOR 9
@@ -68,7 +71,7 @@ static char *header_section = NULL; /* start with no header section */
 typedef union {
 char *strtype;
 } YYSTYPE;
-#line 72 "conf_parse.c"
+#line 75 "conf_parse.c"
 #define YYERRCODE 256
 #define LEFT_BRACKET 257
 #define RIGHT_BRACKET 258
@@ -237,7 +240,7 @@ yyerror(const char *s)
   exit(1);
   return 1;	/* to full compilers that insist on a return statement */
 }
-#line 241 "conf_parse.c"
+#line 244 "conf_parse.c"
 /* allocate initial stack or double stack size, up to YYMAXDEPTH */
 static int yygrowstack()
 {
@@ -484,7 +487,7 @@ case 15:
 		  }
 		}
 break;
-#line 488 "conf_parse.c"
+#line 491 "conf_parse.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
