@@ -1,8 +1,11 @@
-#ifndef lint
-static char const 
-yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.34 2002/04/09 11:39:05 ru Exp $";
-#endif
 #include <stdlib.h>
+#ifndef lint
+#ifdef __unused
+__unused
+#endif
+static char const 
+yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.37 2003/02/12 18:03:55 davidc Exp $";
+#endif
 #define YYBYACC 1
 #define YYMAJOR 1
 #define YYMINOR 9
@@ -57,7 +60,7 @@ typedef union {
 	fsi_mount *m;
 	fsmount *f;
 } YYSTYPE;
-#line 61 "fsi_gram.c"
+#line 64 "fsi_gram.c"
 #define YYERRCODE 256
 #define tARCH 257
 #define tAS 258
@@ -808,7 +811,7 @@ case 56:
 #line 437 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown mount attribute"); }
 break;
-#line 812 "fsi_gram.c"
+#line 815 "fsi_gram.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
